# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           miglayout
Version:        3.7.3.1
Release:        1%{?dist}
Summary:        Java layout manager for Swing, SWT and JavaFX

Group:          Development/Libraries
License:        BSD or GPL
URL:            http://www.miglayout.com/

Source0:        miglayout-3.7.3.1.tgz
# svn export svn://mig-svn.no-ip.org/miglayout2/trunk miglayout-3.7.3.1
# tar czf miglayout-3.7.3.1.tgz miglayout-3.7.3.1/

Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml 
Patch0:         miglayout-pom.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-changes
BuildRequires:  maven2-plugin-checkstyle
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-pmd
BuildRequires:  maven2-plugin-project-info-reports
BuildRequires:  maven2-plugin-source
BuildRequires:  maven-jxr
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  maven-surefire-report-maven-plugin
BuildRequires:  geronimo-genesis
BuildRequires:  mojo-maven2-plugin-cobertura
BuildRequires:  mojo-maven2-plugin-findbugs
BuildRequires:  mojo-maven2-plugin-javancss
BuildRequires:  mojo-maven2-plugin-jdepend
BuildRequires:  mojo-maven2-plugin-retrotranslator
BuildRequires:  mojo-maven2-plugin-taglist
BuildRequires:  apache-commons-parent
BuildRequires:  junit44
BuildRequires:  eclipse-swt
BuildRequires:  substance
BuildRequires:  gmaven-runtime-1.5
BuildRequires:  groovy15

Requires:  java >= 0:1.6.0
Requires:  jpackage-utils >= 0:1.7.5
Requires:  eclipse-swt
Requires:  substance

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

BuildArch:      noarch

%description
For Java developers writing GUI layouts by hand that wants 
simplicity, power and automatic per platform fidelity, that
are dissatisfied with the current layout managers in Swing 
and SWT, MiGLayout solves your layout problems. User 
interfaces created with MiGLayout is easy to maintain, you 
will understand how the layout will look like just by 
looking at the source code.
MiGLayout is a superbly versatile SWT/Swing layout manager 
that makes layout problems trivial. It is using String or 
API type-checked constraints to format the layout. MiGLayout 
can produce flowing, grid based, absolute (with links), 
grouped and docking layouts. You will never have to switch 
to another layout manager ever again! MiGLayout is created 
to be to manually coded layouts what Matisse/GroupLayout is 
to IDE supported visual layouts.

%package javadoc 
Summary:        Javadocs for %{name} 
Group:          Documentation 
Requires:       %{name} = %{version}-%{release} 
 
%description javadoc 
%{summary}. 

%prep
%setup -q 
cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
mkdir external_repo
ln -s %{_javadir} external_repo/JPP
%patch0 -b .sav0

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Djava.awt.headless=true -Daggregate=true"

PTF=$(ls /usr/lib*/eclipse/plugins/org.eclipse.swt.gtk.linux*.jar)
echo $PTF | grep lib64
if [ $? -eq 0 ]; then
%{_bindir}/mvn-jpp install:install-file -DgroupId=org.eclipse.swt.gtk.linux -DartifactId=x86_64 -Dversion=3.3.0-v3346 -Dpackaging=jar -Dfile=${PTF}
else
%{_bindir}/mvn-jpp install:install-file -DgroupId=org.eclipse.swt.gtk.linux -DartifactId=x86 -Dversion=3.3.0-v3346 -Dpackaging=jar -Dfile=${PTF}
fi

export MAVEN_SETTINGS=$(pwd)/settings.xml
%{_bindir}/mvn-jpp \
        -e \
        -s ${MAVEN_SETTINGS} \
        install javadoc:javadoc

%install
%__rm -rf %{buildroot}

# jar
%__mkdir_p %{buildroot}%{_javadir}/%{name}
%__install -m 644 target/%{name}-%{version}-ideutil.jar %{buildroot}%{_javadir}/%{name}/%{name}-ideutil-%{version}.jar
%__install -m 644 target/%{name}-%{version}-ideutil-java14.jar %{buildroot}%{_javadir}/%{name}/%{name}-ideutil-java14-%{version}.jar
%__install -m 644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-%{version}.jar
%__install -m 644 target/%{name}-%{version}-swing.jar %{buildroot}%{_javadir}/%{name}/%{name}-swing-%{version}.jar
%__install -m 644 target/%{name}-%{version}-swing-java14.jar %{buildroot}%{_javadir}/%{name}/%{name}-swing-java14-%{version}.jar
%__install -m 644 target/%{name}-%{version}-swt.jar %{buildroot}%{_javadir}/%{name}/%{name}-swt-%{version}.jar
%__install -m 644 target/%{name}-%{version}-swt-java14.jar %{buildroot}%{_javadir}/%{name}/%{name}-swt-java14-%{version}.jar
(cd %{buildroot}%{_javadir}/%{name} && for jar in *-%{version}*; do \
%__ln_s ${jar} ${jar/-%{version}/}; done)

# poms
%__mkdir_p %{buildroot}%{_datadir}/maven2/poms
%__install -m 644 pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-%{name}.pom
%add_to_maven_depmap com.miglayout %{name} %{version} JPP/%{name} %{name}

# javadoc 
%__mkdir_p %{buildroot}%{_javadocdir}/%{name}-%{version} 
%__cp -a target/site/apidocs/* \
               %{buildroot}%{_javadocdir}/%{name}-%{version}
%__ln_s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name} 

%clean
%__rm -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc 
%defattr(-,root,root,-) 
%{_javadocdir}/%{name}-%{version} 
%{_javadocdir}/%{name} 

%changelog
* Sun Oct 17 2010 Ralph Apel <r.apel@r-apel.de> 3.7.3.1-1
- First release

